@@ -277,9 +277,12 @@ def admin_if_last_member(instance, **kwargs):
 
 @receiver(post_delete, sender=CommunityMember)
 def admin_if_last_member(instance, **kwargs):
-    if not Model.is_external(instance.community):
-        if instance.community.members.count() == 1 and not instance.community.members.first().is_admin:
-            CommunityMember.objects.filter(community=instance.community).update(is_admin=True)
-        # Community must have an admin. It'll be you so.
-        if instance.community.members.count() == 0:
-            CommunityMember.objects.get_or_create(community=instance.community, user=getattr(instance, "modification_user", None), is_admin=True)
+    try:
+        if instance.community and not Model.is_external(instance.community):
+            if instance.community.members.count() == 1 and not instance.community.members.first().is_admin:
+                CommunityMember.objects.filter(community=instance.community).update(is_admin=True)
+            # Community must have an admin. It'll be you so.
+            if instance.community.members.count() == 0:
+                CommunityMember.objects.get_or_create(community=instance.community, user=getattr(instance, "modification_user", None), is_admin=True)
+    except ObjectDoesNotExist:
+        pass
\ No newline at end of file
